@@ -1,4 +1,5 @@
-import snappi as trexapi
+import snappi
+import snappi_trex
 
 
 
@@ -12,7 +13,7 @@ def hello_snappi():
     - Validate that captured UDP packets on both the ports are as expected.
     """
     # create a new API instance where host points to controller
-    api = trexapi.api(host='https://localhost', ext='trex')
+    api = snappi.api(host='https://localhost', ext='trex')
     
     # and an empty traffic configuration to be pushed to controller later on
     cfg = api.config()
