@@ -1,7 +1,7 @@
 import json
 import snappi
-import ValueOptions
-import stl_path
+import snappi_trex.valueoptions
+import snappi_trex.stl_path
 from trex.stl.api import *
 
 
